pub enum ScheduleAfterRejection {
DeadlineOverflow,
QueueGenerationExhausted,
QueueSequenceExhausted,
}Expand description
Exact reason a relative timer request was rejected before scheduling.
Variants
DeadlineOverflow
Adding the delay to the interpreter’s current instant overflowed.
QueueGenerationExhausted
The timer queue cannot issue another internal generation.
QueueSequenceExhausted
The timer queue cannot issue another stable insertion sequence.