pub enum ScheduleAtRejection {
QueueGenerationExhausted,
QueueSequenceExhausted,
}Expand description
Exact reason an absolute timer request was rejected before scheduling.
Variants
QueueGenerationExhausted
The timer queue cannot issue another internal generation.
QueueSequenceExhausted
The timer queue cannot issue another stable insertion sequence.