pub struct MachineError<A, M, E> {
pub event: User<A, M>,
pub cause: E,
}Expand description
Controlled machine rejection with the complete unaccepted mailbox input.
Fields
event: User<A, M>Exact user event whose transition or induced drain was rejected.
cause: EDomain error returned by the phase function.