pub struct CancelObservation<P: Protocol> { /* private fields */ }Expand description
One affine attempt to cancel the exact accepted relationship.
Cancellation acknowledgements require their own typed report ingress.
fn accepts<Event, Sends: behavior::SendsFor<Event>>() {}
pub fn cancellation_acknowledgement<P>() where P: behavior::Protocol, P::Addr: behavior::RecipientAddress {
accepts::<behavior::EventLayer<behavior_actors::EstablishedObservation<P>, behavior::User<P::Addr, P::Msg>>, behavior::InterpreterRequests<behavior_actors::CancelObservation<P>>>();
}ⓘ
fn accepts<Event, Sends: behavior::SendsFor<Event>>() {}
pub fn cancellation_acknowledgement<P>() where P: behavior::Protocol, P::Addr: behavior::RecipientAddress {
accepts::<behavior::User<P::Addr, P::Msg>, behavior::InterpreterRequests<behavior_actors::CancelObservation<P>>>();
}Implementations
Sourceimpl<P: Protocol> CancelObservation<P>
impl<P: Protocol> CancelObservation<P>
pub fn new(authority: ObservationAuthority<P>) -> Self
pub fn id(&self) -> ObservationId
pub fn relationship(&self) -> &ObservationRelationship<P>
Recover the same permission from an unconsumed cancellation request.
Sourcepub fn into_relationship(self) -> ObservationRelationship<P>
pub fn into_relationship(self) -> ObservationRelationship<P>
Consume permission and retain the exact non-authorizing receipt.
pub fn interpret<I>(self, interpreter: &mut I) -> I::Output
pub fn settle<I>( self, interpreter: &mut I, ) -> ItemSettlement<Self, (), Never, Never>