pub struct ObserveCreation<P: Protocol, Occurrence> {
pub creation: CreationId,
/* private fields */
}Expand description
Ask the local interpreter to return the committed result of the same-action creation ID through the behavior’s typed creation-result lane.
Equal address and message types do not make child protocols substitutable:
ⓘ
struct Store;
struct Gateway;
impl behavior::Protocol for Store {
type Addr = behavior::MailAddr;
type Msg = ();
}
impl behavior::Protocol for Gateway {
type Addr = behavior::MailAddr;
type Msg = ();
}
let creation = behavior::CreationSequence::new()
.issue()
.expect("the child creation ID exists");
let gateway = behavior_actors::ObserveCreation::<Gateway, behavior::ChildHead>::new(creation);
let _: behavior_actors::ObserveCreation<Store, behavior::ChildHead> = gateway;Fields
creation: CreationIdImplementations
Sourceimpl<P: Protocol, Occurrence> ObserveCreation<P, Occurrence>
impl<P: Protocol, Occurrence> ObserveCreation<P, Occurrence>
pub const fn new(creation: CreationId) -> Self